;; Generated package description from inspector.el  -*- no-byte-compile: t -*-
(define-package "inspector" "0.36" "Tool for inspection of Emacs Lisp objects" '((emacs "27.1")) :commit "4e85b25e3e80c9989fcf7f518606837a54d9fab6" :authors '(("Mariano Montone" . "marianomontone@gmail.com")) :maintainer '("Mariano Montone" . "marianomontone@gmail.com") :keywords '("debugging" "tool" "lisp" "development") :url "https://github.com/mmontone/emacs-inspector")
